summaryrefslogtreecommitdiff
path: root/proto/static/static.h
diff options
context:
space:
mode:
Diffstat (limited to 'proto/static/static.h')
-rw-r--r--proto/static/static.h3
1 files changed, 1 insertions, 2 deletions
diff --git a/proto/static/static.h b/proto/static/static.h
index bfcbd8c3..0976a9c9 100644
--- a/proto/static/static.h
+++ b/proto/static/static.h
@@ -42,9 +42,8 @@ struct static_route {
byte active; /* Next hop is active (nbr/iface/BFD available) */
byte weight; /* Multipath next hop weight */
byte use_bfd; /* Configured to use BFD */
- byte label_count; /* Number of labels in stack */
struct bfd_request *bfd_req; /* BFD request, if BFD is used */
- u32 *label_stack; /* Label stack if label_count > 0 */
+ mpls_label_stack *mls; /* MPLS label stack; may be NULL */
};
/*